//
//  CustomAnnotationViewController.swift
//  Lite3DMapDemo-swift
//
//  Created by JZ on 2021/2/25.
//

import Foundation

class CustomAnnotationViewController: MAMapBaseViewController {
    
    var calloutView:CustomCalloutView?
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        //加载地图
        map.createMap()
        //在视图上添加webView
        self.addWebView()
        //初始化自定义calloutView
        self.initCalloutView();
    }
    
    let kCalloutWidth  = 200.0
    let kCalloutHeight = 70.0
    
    func initCalloutView(){
        self.calloutView = CustomCalloutView.init(frame: CGRect.init(x: 0, y: 0, width: kCalloutWidth, height: kCalloutHeight))
        
        let btn = UIButton.init(type: UIButton.ButtonType.roundedRect)
        btn.frame = CGRect.init(x: 10, y: 10, width: 40, height: 40)
        btn.setImage(UIImage.init(named: "food"), for: UIControl.State.normal)
        btn.backgroundColor = UIColor.white
        btn.setTitleColor(UIColor.red, for: UIControl.State.highlighted)
        btn.addTarget(self, action: #selector(btnAction), for: UIControl.Event.touchUpInside)
        self.calloutView?.addSubview(btn)
        
        let name:UILabel = UILabel.init(frame: CGRect.init(x: 60, y: 10, width: 100, height: 30))
        name.backgroundColor = UIColor.clear
        name.textColor = UIColor.white
        name.text = "Hello Amap!"
        self.calloutView?.addSubview(name)
    }

    @objc func btnAction(){
        print("Test Button Clicked!")
    }
    
    //MARK: - MAMapViewDelegate
    func mapReady(_ map: MAMap) {
        let annotation = MAPointAnnotation.init()
        annotation.coordinate = CLLocationCoordinate2D.init(latitude: 39.989631, longitude: 116.481018);
        annotation.title    = "AutoNavi";
        annotation.subtitle = "CustomAnnotationView";
        
        self.map.addAnnotation(annotation)
        self.map.selectAnnotation(annotation, animated: true)
    }
    
    func map(_ map: MAMap, viewFor annotation: MAAnnotation) -> MAAnnotationView! {
        if annotation.isKind(of: MAPointAnnotation.self) {
            let annotationView = MAAnnotationView.init(annotation: annotation)
            annotationView?.canShowCallout = true
            annotationView?.isDraggable = true
            annotationView?.customCalloutView = self.calloutView
            
            annotationView?.image = UIImage.init(named: "restaurant")
            annotationView?.centerOffset = CGPoint.init(x: 0, y: -16)
            annotationView?.calloutOffset = CGPoint.init(x: 0, y: -16)
            return annotationView!
        }
        return nil
    }
}
