//
//  OperatemapController.swift
//  Lite3DMapDemo-swift
//
//  Created by JZ on 2021/2/25.
//

import Foundation

class OperateMapViewController: MAMapBaseViewController {
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        //加载地图
        map.createMap()
        //在视图上添加webView
        self.addWebView()
        
        let sws = makeSwitchsPannelView()
        sws.center = CGPoint.init(x: sws.bounds.midX + 10, y: self.view.bounds.height - sws.bounds.midY - 20)
        
        sws.autoresizingMask = [UIView.AutoresizingMask.flexibleTopMargin, UIView.AutoresizingMask.flexibleRightMargin]
        self.view.addSubview(sws)
        
        let cameraPanel = makeMapDegreePannelView()
        cameraPanel.center = CGPoint.init(x: self.view.bounds.width - cameraPanel.bounds.midX - 10,
                                          y: self.view.bounds.height - cameraPanel.bounds.midY - 10)
        
        cameraPanel.autoresizingMask = [UIView.AutoresizingMask.flexibleTopMargin , UIView.AutoresizingMask.flexibleLeftMargin]
        self.view.addSubview(cameraPanel)
    }
    
    func makeMapDegreePannelView() -> UIView {
        let ret = UIView.init(frame: CGRect.init(x: 0, y: 0, width: 53, height: 98))
        
        let incBtn = UIButton.init(frame: CGRect.init(x: 0, y: 0, width: 53, height: 49))
        incBtn.setImage(UIImage.init(named: "increase"), for: UIControl.State.normal)
        incBtn.sizeToFit()
        incBtn.addTarget(self, action: #selector(self.cameraDegreePlusAction), for: UIControl.Event.touchUpInside)
        
        let decBtn = UIButton.init(frame: CGRect.init(x: 0, y: 49, width: 53, height: 49))
        decBtn.setImage(UIImage.init(named: "decrease"), for: UIControl.State.normal)
        decBtn.sizeToFit()
        decBtn.addTarget(self, action: #selector(self.cameraDegreeMinusAction), for: UIControl.Event.touchUpInside)
        
        ret.addSubview(incBtn)
        ret.addSubview(decBtn)
        
        return ret
    }
    
    func makeSwitchsPannelView() -> UIView {
        let ret = UIView.init()
        ret.backgroundColor = UIColor.white
        
        let sw1 = UISwitch.init()
        let sw2 = UISwitch.init()
        let sw3 = UISwitch.init()
        
        let l1 = UILabel.init(frame: CGRect.init(x: 0, y: 0, width: 70, height: sw1.bounds.height))
        l1.textColor = UIColor.black
        l1.text = "拖拽:"
        
        let l2 = UILabel.init(frame: CGRect.init(x: 0, y: l1.frame.maxY + 5, width: 70, height: sw1.bounds.height))
        l2.textColor = UIColor.black
        l2.text = "缩放:"
        
        let l3 = UILabel.init(frame: CGRect.init(x: 0, y: l2.frame.maxY + 5, width: 70, height: sw1.bounds.height))
        l3.textColor = UIColor.black
        l3.text = "旋转:"
        
        ret.addSubview(l1)
        ret.addSubview(sw1)
        ret.addSubview(l2)
        ret.addSubview(sw2)
        ret.addSubview(l3)
        ret.addSubview(sw3)
        
        var temp = sw1.frame
        temp.origin.x = l1.frame.maxX + 5
        sw1.frame = temp
        
        temp = sw2.frame
        temp.origin.x = l2.frame.maxX + 5
        temp.origin.y = l2.frame.minY
        sw2.frame = temp
        
        temp = sw3.frame
        temp.origin.x = l3.frame.maxX + 5
        temp.origin.y = l3.frame.minY
        sw3.frame = temp
        
        sw1.addTarget(self, action: #selector(self.enableDrag(sender:)), for: UIControl.Event.valueChanged)
        sw2.addTarget(self, action: #selector(self.enableZoom(sender:)), for: UIControl.Event.valueChanged)
        sw3.addTarget(self, action: #selector(self.enableRotate(sender:)), for: UIControl.Event.valueChanged)
        
        sw1.isOn = map.isScrollEnabled
        sw2.isOn = map.isZoomEnabled
        sw3.isOn = map.isRotateEnabled
        
        ret.bounds = CGRect.init(x: 0, y: 0, width: sw3.frame.maxX, height: l3.frame.maxY)
        
        return ret
    }
    
    //MARK: - event handling
    @objc func enableDrag(sender:UISwitch) {
        map.isScrollEnabled = sender.isOn
    }
    
    @objc func enableZoom(sender:UISwitch) {
        map.isZoomEnabled = sender.isOn
    }
    
    @objc func enableRotate(sender:UISwitch) {
        map.isRotateEnabled = sender.isOn
    }
    
    @objc func cameraDegreePlusAction() {
        map.cameraDegree += 5
    }
    
    @objc func cameraDegreeMinusAction() {
        map.cameraDegree -= 5
    }
    
}
