//
//  PointToLineDistanceViewController.swift
//  Lite3DMapDemo-swift
//
//  Created by JZ on 2021/2/26.
//

import Foundation

class PointToLineDistanceViewController: MAMapBaseViewController {
    
    var pin: MAPointAnnotation!
    var lineCoords:[CLLocationCoordinate2D] = []
    var line:MAPolyline!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        //加载地图
        map.createMap()
        //在视图上添加webView
        addWebView()
    }
    
    func initAnnotations() {
        pin = MAPointAnnotation.init()
        pin.coordinate = CLLocationCoordinate2DMake(39.992520, 116.336170)
        pin.title = "拖动我哦"
        
        map.addAnnotations([pin!])
        map.selectAnnotation(pin, animated: true)
    }
    
    func initLine() {
        lineCoords = [CLLocationCoordinate2DMake(39.925539, 116.0),
                      CLLocationCoordinate2DMake(39.925539, 116.5)]
        
        line = MAPolyline.init(coordinates: &lineCoords, count: UInt(lineCoords.count))
        map.add(line)
    }
    
    //MARK: - mapview delegate
    func mapReady(_ map: MAMap) {
        initAnnotations()
        initLine()
    }
    
    func map(_ map: MAMap!, viewFor annotation: MAAnnotation!) -> MAAnnotationView! {
        
        if annotation.isKind(of: MAPointAnnotation.self) {
            if annotation.isKind(of: MAPointAnnotation.self) {
                let annotationView = MAPinAnnotationView.init(annotation: annotation)
                annotationView?.canShowCallout = true
                annotationView?.isDraggable = true
                
                return annotationView!
            }
        }
        
        return nil
    }
    
    func map(_ map:MAMap, annotationView:MAAnnotationView, didChange newState:MAAnnotationViewDragState, fromOldState:MAAnnotationViewDragState) {
        if(newState == MAAnnotationViewDragState.ending) {
            let loc = self.pin.coordinate
            let p = MAMapPointForCoordinate(loc)
            let lineBegin = MAMapPointForCoordinate(lineCoords[0])
            let lineEnd = MAMapPointForCoordinate(lineCoords[1])
            
            let distance =  CommonUtility.distance(to: p, fromLineSegmentBetween: lineBegin, and: lineEnd)
            self.view.makeToast(String.init(format: "distance = %.2f", distance), duration: 1.5)
        }
    }
    
    func map(_ map: MAMap!, rendererFor overlay: MAOverlay!) -> MAOverlayRenderer! {
        
        if (overlay.isKind(of: MAPolyline.self))
        {
            let renderer = MAPolylineRenderer.init(polyline: (overlay as! MAPolyline))
            renderer?.strokeColor = UIColor.blue
            renderer?.lineWidth = 2.0
            renderer?.lineDashType = kMALineDashTypeNone
            
            return renderer;
        }
        
        return nil;
    }
    
    
}
