//
//  UserLocationViewController.swift
//  Lite3DMapDemo-swift
//
//  Created by JZ on 2021/2/26.
//

import Foundation

class UserLocationViewController: LocationBaseViewController {
    
    var locationSegmentControl: UISegmentedControl!
    var modeSegmentControl: UISegmentedControl!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        //加载地图
        map.createMap()
        //在视图上添加webView
        self.addWebView()
        
        initToolBar()
        initObserver()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        self.navigationController?.setToolbarHidden(false, animated: true)
    }
    
    override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)
        // 开启定位
        startLocation()
        map.userTrackingMode = MAUserTrackingMode.follow
    }
    
    deinit {
        map.removeObserver(self, forKeyPath: "showsUserLocation")
    }
    
    func initToolBar() {
        let flexibleItem = UIBarButtonItem(barButtonSystemItem: UIBarButtonItem.SystemItem.flexibleSpace, target: nil, action: nil)
        
        let locationSegmentControl = UISegmentedControl(items: ["Start", "Stop"])
        locationSegmentControl.addTarget(self, action:#selector(self.locationAction(sender:)), for: UIControl.Event.valueChanged)
        locationSegmentControl.selectedSegmentIndex = 1
        let locationSegmentItem = UIBarButtonItem(customView: locationSegmentControl)
        
        let modeSegmentControl = UISegmentedControl(items: ["None", "Follow", "Heading"])
        modeSegmentControl.addTarget(self, action:#selector(self.modeAction(sender:)), for: UIControl.Event.valueChanged)
        modeSegmentControl.selectedSegmentIndex = 0
        let modeSegmentItem = UIBarButtonItem(customView: modeSegmentControl)
        
        self.toolbarItems = [flexibleItem, locationSegmentItem, flexibleItem, modeSegmentItem, flexibleItem]
        
        self.locationSegmentControl = locationSegmentControl
        self.modeSegmentControl = modeSegmentControl
        
    }
    
    func initObserver() {
        map.addObserver(self, forKeyPath: "showsUserLocation", options: NSKeyValueObservingOptions.new, context: nil)
    }
    
    //MARK: - Actions
    override func didUpdateLocation(_ location: CLLocation, reGeocode: AMapLocationReGeocode?) {
        map.setUserLocation(location, coordinateType: AMapCoordinateType.aMap)
    }
    
    override func didUpdateHeading(_ newHeading: CLHeading) {
        map.setUserHeading(newHeading)
    }
    
    @objc func locationAction(sender: UISegmentedControl)
    {
        if sender.selectedSegmentIndex == 0 {
            map.showsUserLocation = true
        }
        else {
            map.showsUserLocation = false
        }
    }
    
    @objc func modeAction(sender: UISegmentedControl)
    {
        map.userTrackingMode = MAUserTrackingMode(rawValue: sender.selectedSegmentIndex)!
    }
    
    //MARK: - MAMapViewDelegate
    func mapReady(_ map: MAMap) {
        self.map.showsUserLocation = true

        startLocation()
        startLocationHeading()
        
        //自定义定位圈
        self.map.userLocation.title = "您的位置在这里";
        let represent:MAUserLocationRepresentation = MAUserLocationRepresentation.init()
        represent.showsAccuracyRing = true
        represent.fillColor = UIColor.init(red: 1, green: 0, blue: 0, alpha: 3)
        represent.strokeColor = UIColor.lightGray
        represent.lineWidth = 2.0
        represent.image = UIImage.init(named: "userPosition")
        map.update(represent)
    }
    
    func map(_ map: MAMap!, didChange mode: MAUserTrackingMode, animated: Bool) {
        self.modeSegmentControl.selectedSegmentIndex = mode.rawValue
    }
    
    //MARK: - NSKeyValueObservering
    
    override func observeValue(forKeyPath keyPath: String?, of object: Any?, change: [NSKeyValueChangeKey : Any]?, context: UnsafeMutableRawPointer?) {
        
        if (keyPath != nil) && (keyPath == "showsUserLocation") {
            let locationValue: NSNumber? = change?[NSKeyValueChangeKey.newKey] as! NSNumber?
            if locationValue != nil && locationValue!.boolValue {
                locationSegmentControl.selectedSegmentIndex = 0
            }
            else {
                locationSegmentControl.selectedSegmentIndex = 1
            }
            
        }
    }
    
}
