//
//  ViewController.m
//  MAMapKit_3D_Demo
//
//  Created by 翁乐 on 8/9/16.
//  Copyright © 2016 Autonavi. All rights reserved.
//

#import "MainViewController.h"
#define MainViewControllerTitle @"高德轻量版地图API-3D"

@interface MainViewController ()<UITableViewDelegate, UITableViewDataSource>
{
    UITableView * _mainTableView;
    NSArray     * _titles;
    NSArray     * _className;
}

@end

@implementation MainViewController


#pragma mark - tableView delegate
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    
    NSArray *rows = [[_titles objectAtIndex:indexPath.section] allValues].firstObject;
    NSString *className = [[rows objectAtIndex:indexPath.row] allValues].firstObject;
    NSString *title = [[rows objectAtIndex:indexPath.row] allKeys].firstObject;
    
    BOOL handled = NO;
    if(self.delegate) {
        handled = [self.delegate viewController:self itemSelected:className title:title];
    }
    
    if(handled) {
        return;
    }
    
    UIViewController *subViewController = [[NSClassFromString(className) alloc] init];
    NSString *xibBundlePath = [[NSBundle mainBundle] pathForResource:[NSString stringWithFormat:@"%@",className] ofType:@"xib"];
    if (xibBundlePath.length) {
        subViewController = [[NSClassFromString(className) alloc] initWithNibName:className bundle:nil];
    }
    subViewController.title = title;
    
    [self.navigationController pushViewController:subViewController animated:YES];
}

#pragma mark - tableView DataSource
-(NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return [_titles count];
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [[[_titles objectAtIndex:section] allValues].firstObject count];
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return 44;
}

-(UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *mainCellIdentifier = @"com.autonavi.mainCellIdentifier";
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:mainCellIdentifier];
    NSArray *rows = [[_titles objectAtIndex:indexPath.section] allValues].firstObject;
    NSString *className = [[rows objectAtIndex:indexPath.row] allValues].firstObject;
    NSString *title = [[rows objectAtIndex:indexPath.row] allKeys].firstObject;
    if(self.delegate) {
        className = [self.delegate viewController:self displayTileOf:className];
        className = [className componentsSeparatedByString:@"."].lastObject;
    }
    
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:mainCellIdentifier];
        cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
        cell.detailTextLabel.lineBreakMode = NSLineBreakByCharWrapping;
        cell.detailTextLabel.numberOfLines = 0;
        cell.detailTextLabel.font = [UIFont systemFontOfSize:12];
        cell.textLabel.font = [UIFont systemFontOfSize:13];
    }
    
    cell.detailTextLabel.text = className;
    cell.textLabel.text = title;
    
    return cell;
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section {
    return 40;
}

- (UIView *)tableView:(UITableView *)tableView viewForHeaderInSection:(NSInteger)section {
    UIView *header = [[UIView alloc] initWithFrame:CGRectMake(0, 0, _mainTableView.bounds.size.width, 40)];
    UILabel *label = [[UILabel alloc] init];
    label.font = [UIFont systemFontOfSize:14];
    label.text = [[_titles objectAtIndex:section] allKeys].firstObject;
    label.numberOfLines = 1;
    [label sizeToFit];
    CGRect frame = label.frame;
    frame.origin.x = 15;
    frame.origin.y = header.bounds.size.height - frame.size.height;
    label.frame = frame;
    [header addSubview:label];
    return header;
}
#pragma mark - init
- (void)initTitles
{
    ///主页面标签title
    _titles = @[@{@"创建地图":@[
                          @{@"切换地图图层":@"MapTypeViewController"},
                          @{@"提前加载地图资源":@"PreLoadMapViewController"},
                          ]
                  },
                @{@"与地图交互":@[
                          @{@"手势交互":@"OperateMapViewController"},
                          @{@"方法交互(改变地图缩放级别)":@"ChangeZoomViewController"},
                          @{@"方法交互(改变地图中心点)":@"ChangeCenterViewController"},
                          @{@"方法交互(限制地图的显示范围)":@"MapBoundaryViewController"},
                          @{@"地图长按事件":@"LongGestureViewController"},
                          ]
                  },
                
                @{@"在地图上绘制":@[
                          @{@"显示定位蓝点(默认样式)":@"UserLocationViewController"},
                          @{@"绘制点标记":@"AnnotationViewController"},
                          @{@"自定义CalloutView":@"CustomAnnotationViewController"},
                          @{@"绘制折线":@"LinesOverlayViewController"},
                          @{@"绘制面(圆形)":@"CircleOverlayViewController"},
                          @{@"绘制面(矩形)":@"PolygonOverlayViewController"},
                          @{@"点平滑移动":@"MovingAnnotationViewController"},
                          @{@"多彩线":@"ColoredLinesOverlayViewController"},
                          ]
                  },
                @{@"地图计算工具":@[
                          @{@"屏幕坐标与经纬度转换":@"CoordinateConvertViewController"},
                          @{@"坐标转换":@"CooridinateSystemConvertController"},
                          @{@"两点间距离计算":@"PointToPointDistanceViewController"},
                          @{@"点与线的距离计算":@"PointToLineDistanceViewController"},
                          @{@"判断点是否在多边形内":@"InsideTestViewController"}
                          ]
                  }
    ];
    
    if(self.delegate) {
        NSMutableArray *titles = [NSMutableArray array];
        for(int section = 0; section < _titles.count; ++section) {
            NSDictionary *sectionItem = [_titles objectAtIndex:section];
            NSString *titleKey = [sectionItem allKeys].firstObject;
            NSArray *rows = [sectionItem allValues].firstObject;
            NSMutableArray *arr = [NSMutableArray array];
            for(int row = 0; row < rows.count; ++row) {
                NSDictionary *rowItem = [rows objectAtIndex:row];
                NSString *className = [rowItem allValues].firstObject;
                if([self.delegate viewController:self displayTileOf:className]) {
                    [arr addObject:rowItem];
                }
            }
            
            if(arr.count > 0) {
                [titles addObject:@{titleKey:arr}];
            }
        }
        
        _titles = titles;
    }
}

#pragma mark - life cycle

- (void)viewDidLoad {
    [super viewDidLoad];
    
    self.title = MainViewControllerTitle;
    
    [self initTitles];
    
    _mainTableView = [[UITableView alloc] initWithFrame:self.view.bounds style:UITableViewStyleGrouped];
    _mainTableView.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth;
    _mainTableView.sectionHeaderHeight = 10;
    _mainTableView.sectionFooterHeight = 0;
    _mainTableView.delegate = self;
    _mainTableView.dataSource = self;
    
    [self.view addSubview:_mainTableView];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
    self.navigationController.navigationBar.barStyle = UIBarStyleDefault;
    self.navigationController.navigationBar.translucent = NO;
    [self.navigationController setToolbarHidden:YES animated:animated];
}

@end
