//
//  AnnotationViewController.m
//  Category_demo
//
//  Created by songjian on 13-3-21.
//  Copyright (c) 2013年 songjian. All rights reserved.
//

#import "AnnotationViewController.h"

@interface AnnotationViewController ()<MAMapDelegate>

@property (nonatomic, strong) NSMutableArray *annotations;

@end

@implementation AnnotationViewController

#pragma mark - Life Cycle

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    //加载地图
    [self.map createMap];
    //在视图上添加webView
    [self addWebView];
    [self initAnnotations];
}

#pragma mark - Initialization
- (void)initAnnotations
{
    self.annotations = [NSMutableArray array];
    
    CLLocationCoordinate2D coordinates[10] = {
        {39.992520, 116.336170},
        {39.992520, 116.336170},
        {39.998293, 116.352343},
        {40.004087, 116.348904},
        {40.001442, 116.353915},
        {39.989105, 116.353915},
        {39.989098, 116.360200},
        {39.998439, 116.360201},
        {39.979590, 116.324219},
        {39.978234, 116.352792}};
    
    for (int i = 0; i < 10; ++i)
    {
        MAPointAnnotation *a1 = [[MAPointAnnotation alloc] init];
        a1.coordinate = coordinates[i];
        a1.title      = [NSString stringWithFormat:@"anno: %d", i];
        [self.annotations addObject:a1];
    }
}

#pragma mark - Map Delegate

- (void)mapReady:(MAMap *)map{
    [self.map addAnnotations:self.annotations];
    [self.map showAnnotations:self.annotations animated:YES];
}

/*!
 @brief 根据anntation生成对应的View
 @param map 地图
 @param annotation 指定的标注
 @return 生成的标注View
 */
- (MAAnnotationView*)map:(MAMap *)map viewForAnnotation:(id <MAAnnotation>)annotation {
    if ([annotation isKindOfClass:[MAPointAnnotation class]])
    {
        MAPinAnnotationView *annotationView = [[MAPinAnnotationView alloc] initWithAnnotation:annotation];
        
        annotationView.canShowCallout               = YES;
        annotationView.draggable                    = YES;
        annotationView.rightCalloutAccessoryView    = [UIButton buttonWithType:UIButtonTypeDetailDisclosure];
        return annotationView;
    }
    
    return nil;
}

/*!
 @brief 当选中一个annotation views时调用此接口
 @param map 地图
 @param view 选中的annotation views
 */
- (void)map:(MAMap *)map didSelectAnnotationView:(MAAnnotationView *)view {
    
}

/*!
 @brief 当取消选中一个annotation views时调用此接口
 @param map 地图
 @param view 取消选中的annotation views
 */
- (void)map:(MAMap *)map didDeselectAnnotationView:(MAAnnotationView *)view {
    
}

/**
 *  标注view的calloutview整体点击时调用此接口
 *
 *  @param map 地图的view
 *  @param view calloutView所属的annotationView
 */
- (void)map:(MAMap *)map didAnnotationViewCalloutTapped:(MAAnnotationView *)view {
    
}

/*!
 @brief 拖动annotation view时view的状态变化，ios3.2以后支持
 @param map 地图
 @param view annotation view
 @param newState 新状态
 @param oldState 旧状态
 */
- (void)map:(MAMap *)map annotationView:(MAAnnotationView *)view didChangeDragState:(MAAnnotationViewDragState)newState fromOldState:(MAAnnotationViewDragState)oldState {
    
}


@end
