//
//  CustomAnnotationViewController.m
//  Lite3DMapDemo
//
//  Created by JZ on 2021/2/19.
//

#import "CustomAnnotationViewController.h"
#import "CustomCalloutView.h"

@interface CustomAnnotationViewController ()

@property (nonatomic, strong) MAPointAnnotation *annotation;
@property (nonatomic, strong) CustomCalloutView *calloutView;

@end

@implementation CustomAnnotationViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    
    //加载地图
    [self.map createMap];
    //在视图上添加webView
    [self addWebView];
    //初始化自定义calloutView
    [self initCalloutView];
}

- (void)addAnnotationWithCooordinate:(CLLocationCoordinate2D)coordinate
{
    MAPointAnnotation *annotation = [[MAPointAnnotation alloc] init];
    annotation.coordinate = coordinate;
    annotation.title    = @"AutoNavi";
    annotation.subtitle = @"CustomAnnotationView";
    
    [self.map addAnnotation:annotation];
    
    [self.map selectAnnotation:annotation animated:YES];
    
    _annotation = annotation;
}

#define kCalloutWidth   200.0
#define kCalloutHeight  70.0

- (void)initCalloutView{
    /* Construct custom callout. */
    self.calloutView = [[CustomCalloutView alloc] initWithFrame:CGRectMake(0, 0, kCalloutWidth, kCalloutHeight)];
    
    UIButton *btn = [UIButton buttonWithType:UIButtonTypeRoundedRect];
    btn.frame = CGRectMake(10, 10, 40, 40);
    [btn setImage:[UIImage imageNamed:@"food.png"] forState:UIControlStateNormal];
    [btn setBackgroundColor:[UIColor whiteColor]];
    [btn setTitleColor:[UIColor redColor] forState:UIControlStateHighlighted];
    [btn addTarget:self action:@selector(btnAction) forControlEvents:UIControlEventTouchUpInside];
    
    [self.calloutView addSubview:btn];
    
    UILabel *name = [[UILabel alloc] initWithFrame:CGRectMake(60, 10, 100, 30)];
    name.backgroundColor = [UIColor clearColor];
    name.textColor = [UIColor whiteColor];
    name.text = @"Hello Amap!";
    [self.calloutView addSubview:name];
}

- (void)btnAction{
    NSLog(@"Test Button Clicked!");
}

#pragma mark ---------------- MAMapDelegate ---------------

- (void)mapReady:(MAMap *)map{
    [self addAnnotationWithCooordinate:CLLocationCoordinate2DMake(39.989631, 116.481018)];
}

- (MAAnnotationView*)map:(MAMap *)map viewForAnnotation:(id <MAAnnotation>)annotation {
    if ([annotation isKindOfClass:[MAPointAnnotation class]])
    {
        MAAnnotationView *annotationView = [[MAAnnotationView alloc] initWithAnnotation:annotation];
        
        annotationView.canShowCallout               = YES;
        annotationView.draggable                    = YES;
        annotationView.customCalloutView            = self.calloutView;
        
        annotationView.image                        = [UIImage imageNamed:@"restaurant.png"];
        annotationView.centerOffset                 = CGPointMake(0, -16);
        annotationView.calloutOffset                = CGPointMake(0, -16);
        return annotationView;
    }
    
    return nil;
}



@end
