//
//  LinesOverlayViewController.m
//  Category_demo
//
//  Created by songjian on 13-3-21.
//  Copyright (c) 2013年 songjian. All rights reserved.
//

#import "LinesOverlayViewController.h"

@interface LinesOverlayViewController ()<MAMapDelegate>

@property (nonatomic, strong) NSArray *lines;

@end

@implementation LinesOverlayViewController
- (void)viewDidLoad
{
    [super viewDidLoad];
    
    [self initLines];
    
    self.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:@"Back"
                                                                             style:UIBarButtonItemStylePlain
                                                                            target:self
                                                                            action:@selector(returnAction)];
    
    //加载地图
    [self.map createMap];
    //在视图上添加webView
    [self addWebView];
    
    [self initSlideView];
}

- (void)viewDidAppear:(BOOL)animated {
    [super viewDidAppear:YES];
}

#pragma mark - Initialization
- (void)initSlideView {
    UILabel *widthLabel = [[UILabel alloc]initWithFrame:CGRectMake(5, 30, 70, 30)];
    widthLabel.text = @"lineWidth:";
    widthLabel.backgroundColor = [UIColor whiteColor];
    widthLabel.textColor = [UIColor blackColor];
    widthLabel.font = [UIFont systemFontOfSize:13];
    [self.view addSubview:widthLabel];
    CGSize size = [UIScreen mainScreen].bounds.size;
    UISlider *widthSlide = [[UISlider alloc]initWithFrame:CGRectMake(80, 30, size.width-100, 30)];
    widthSlide.minimumValue = 5;
    widthSlide.maximumValue = 20;
    widthSlide.value = 5;
    [widthSlide addTarget:self action:@selector(widthSliderValueChanged:) forControlEvents:UIControlEventValueChanged];
    [self.view addSubview:widthSlide];
    
    UILabel *colorLabel = [[UILabel alloc]initWithFrame:CGRectMake(5, 70, 70, 30)];
    colorLabel.text = @"lineColor:";
    colorLabel.backgroundColor = [UIColor whiteColor];
    colorLabel.textColor = [UIColor blackColor];
    colorLabel.font = [UIFont systemFontOfSize:13];
    [self.view addSubview:colorLabel];
    UISlider *colorSlide = [[UISlider alloc]initWithFrame:CGRectMake(80, 70, size.width-100, 30)];
    colorSlide.minimumValue = 0;
    colorSlide.maximumValue = 255;
    colorSlide.value = 50;
    [colorSlide addTarget:self action:@selector(colorSliderValueChanged:) forControlEvents:UIControlEventValueChanged];
    [self.view addSubview:colorSlide];
}
- (void)initLines {
    NSMutableArray *arr = [NSMutableArray array];
    
    //line 1
    CLLocationCoordinate2D line1Points[2];
    line1Points[0].latitude = 39.925539;
    line1Points[0].longitude = 116.279037;
    
    line1Points[1].latitude = 39.925539;
    line1Points[1].longitude = 116.520285;
    
    MAPolyline *line1 = [MAPolyline polylineWithCoordinates:line1Points count:2];
    [arr addObject:line1];
    
    
    //line 2
    CLLocationCoordinate2D line2Points[5];
    line2Points[0].latitude = 39.938698;
    line2Points[0].longitude = 116.275177;
    
    line2Points[1].latitude = 39.966069;
    line2Points[1].longitude = 116.289253;
    
    line2Points[2].latitude = 39.944226;
    line2Points[2].longitude = 116.306076;
    
    line2Points[3].latitude = 39.966069;
    line2Points[3].longitude = 116.322899;
    
    line2Points[4].latitude = 39.938698;
    line2Points[4].longitude = 116.336975;
    
    MAPolyline *line2 = [MAPolyline polylineWithCoordinates:line2Points count:5];
    [arr addObject:line2];
    
    self.lines = [NSArray arrayWithArray:arr];
}

#pragma mark - Action Handlers
- (void)widthSliderValueChanged:(UISlider*)widthSlider{
    float width = widthSlider.value;
    [self.lines enumerateObjectsUsingBlock:^(MAPolyline *polyline, NSUInteger idx, BOOL * _Nonnull stop) {
        MAPolylineRenderer *polylineRenderer = (MAPolylineRenderer *)[self.map rendererForOverlay:polyline];
        polylineRenderer.lineWidth = width;
        [polylineRenderer setNeedsUpdate];
    }];
}

- (void)colorSliderValueChanged:(UISlider*)colorSlider{
    float colorValue = colorSlider.value;
    UIColor *color = [UIColor colorWithRed:colorValue/255.0 green:colorValue/255.0 blue:colorValue/255.0 alpha:1.0];
    [self.lines enumerateObjectsUsingBlock:^(MAPolyline *polyline, NSUInteger idx, BOOL * _Nonnull stop) {
        MAPolylineRenderer *polylineRenderer = (MAPolylineRenderer *)[self.map rendererForOverlay:polyline];
        polylineRenderer.strokeColor = color;
        [polylineRenderer setNeedsUpdate];
    }];
}

- (void)returnAction
{
    [self.navigationController popViewControllerAnimated:YES];
}

#pragma mark - MAMapDelegate

- (void)mapReady:(MAMap *)map{
    [self.map addOverlays:self.lines];
}

- (MAOverlayRenderer *)map:(MAMap *)map rendererForOverlay:(id <MAOverlay>)overlay
{
    if ([overlay isKindOfClass:[MAPolyline class]])
    {
        MAPolylineRenderer *polylineRenderer = [[MAPolylineRenderer alloc] initWithPolyline:overlay];
        polylineRenderer.strokeColor = [UIColor blueColor];
        polylineRenderer.lineWidth   = 5.f;
        
        NSInteger index = [self.lines indexOfObject:overlay];
        if(index == 0) {
            polylineRenderer.lineCapType = kMALineCapSquare;
            polylineRenderer.lineDashType = kMALineDashTypeSquare;
        } else {
            polylineRenderer.lineDashType = kMALineDashTypeNone;
        }
        polylineRenderer.isVisible = YES;
        polylineRenderer.alpha = 0.6;
        return polylineRenderer;
    }
    
    return nil;
}

@end
