//
//  LocationBaseViewController.m
//  Lite3DMapDemo
//
//  Created by JZ on 2020/10/22.
//

#import "LocationBaseViewController.h"

@interface LocationBaseViewController ()<AMapLocationManagerDelegate>
@property(nonatomic, strong) AMapLocationManager *locationManager;
@end

@implementation LocationBaseViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.view.backgroundColor = [UIColor whiteColor];

    [self initLocationManager];
}

- (void)dealloc{
    [self.locationManager stopUpdatingHeading];
    [self.locationManager stopUpdatingLocation];
}

- (void)startLocation{
    [self.locationManager startUpdatingLocation];
}

- (void)startLocationHeading{
    [self.locationManager startUpdatingHeading];
}

- (void)initLocationManager{
    self.locationManager = [[AMapLocationManager alloc] init];
    self.locationManager.delegate = self;
    if (@available(iOS 14.0, *)) {
        self.locationManager.locationAccuracyMode = AMapLocationFullAndReduceAccuracy;
    }
}

- (void)didUpdateLocation:(CLLocation *)location reGeocode:(AMapLocationReGeocode *)reGeocode
{
    NSLog(@"子类使用定位数据需要重写此方法，didUpdateLocation:reGeocode:");
}

- (void)didUpdateHeading:(CLHeading *)newHeading{
    NSLog(@"子类使用定位数据需要重写此方法，didUpdateHeading:");
}

//MARK: -----AMapLocationManagerDelegate
- (void)amapLocationManager:(AMapLocationManager *)manager didUpdateLocation:(CLLocation *)location reGeocode:(AMapLocationReGeocode *)reGeocode
{
    [self didUpdateLocation:location reGeocode:reGeocode];
}

- (void)amapLocationManager:(AMapLocationManager *)manager doRequireLocationAuth:(CLLocationManager *)locationManager
{
    [locationManager requestAlwaysAuthorization];
}

- (void)amapLocationManager:(AMapLocationManager *)manager didUpdateHeading:(CLHeading *)newHeading{
    [self didUpdateHeading:newHeading];
}

- (void)amapLocationManager:(AMapLocationManager *)manager doRequireTemporaryFullAccuracyAuth:(CLLocationManager *)locationManager completion:(void (^)(NSError *))completion
{
    if (@available(iOS 14.0, *)) {
        [locationManager requestTemporaryFullAccuracyAuthorizationWithPurposeKey:@"" completion:completion];
    }
}

@end
