//
//  UserLocationViewController.m
//  Category_demo
//
//  Created by songjian on 13-3-21.
//  Copyright (c) 2013年 songjian. All rights reserved.
//

#import "UserLocationViewController.h"

@interface UserLocationViewController ()<MAMapDelegate>

@property (nonatomic, strong) MAMap *map;

@property (nonatomic, strong) UISegmentedControl *showSegment;

@property (nonatomic, strong) UISegmentedControl *modeSegment;

@property (nonatomic, strong) MAWKWebView *webView;
@end

@implementation UserLocationViewController

#pragma mark - Life Cycle
- (void)viewDidLoad
{
    [super viewDidLoad];
    
    self.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:@"Back"
                                                                             style:UIBarButtonItemStylePlain
                                                                            target:self
                                                                            action:@selector(returnAction)];

    CGSize size = self.view.bounds.size;
    CGFloat height = size.height - MANavHeight;
    self.webView = [[MAWKWebView alloc] initWithFrame:CGRectMake(0, 0, size.width, height)];
    self.map = [[MAMap alloc] initWithWebView:self.webView];
    self.map.delegate = self;
    [self.view addSubview:self.webView.webView];
    [self.map createMap];
    

    [self initToolBar];
    [self initObservers];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
    self.navigationController.toolbar.barStyle      = UIBarStyleDefault;
    self.navigationController.toolbar.translucent   = YES;
    [self.navigationController setToolbarHidden:NO animated:animated];
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
}

#pragma mark - Initialization

- (void)initToolBar
{
    UIBarButtonItem *flexble = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemFlexibleSpace
                                                                             target:nil
                                                                             action:nil];
    
    self.showSegment = [[UISegmentedControl alloc] initWithItems:[NSArray arrayWithObjects:@"Start", @"Stop", nil]];
    [self.showSegment addTarget:self action:@selector(showsSegmentAction:) forControlEvents:UIControlEventValueChanged];
    self.showSegment.selectedSegmentIndex = 0;
    UIBarButtonItem *showItem = [[UIBarButtonItem alloc] initWithCustomView:self.showSegment];
    
    self.modeSegment = [[UISegmentedControl alloc] initWithItems:[NSArray arrayWithObjects:@"None", @"Follow", @"Head", nil]];
    [self.modeSegment addTarget:self action:@selector(modeAction:) forControlEvents:UIControlEventValueChanged];
    self.modeSegment.selectedSegmentIndex = 0;
    UIBarButtonItem *modeItem = [[UIBarButtonItem alloc] initWithCustomView:self.modeSegment];
    
    self.toolbarItems = [NSArray arrayWithObjects:flexble, showItem, flexble, modeItem, flexble, nil];
}

- (void)initObservers
{
    /* Add observer for showsUserLocation. */
    [self.map addObserver:self forKeyPath:@"showsUserLocation" options:NSKeyValueObservingOptionNew context:nil];
}

#pragma mark - action handling
- (void)didUpdateLocation:(CLLocation *)location reGeocode:(AMapLocationReGeocode *)reGeocode{
    if (CLLocationCoordinate2DIsValid(location.coordinate)) {
        [self.map setUserLocation:location coordinateType:AMapCoordinateTypeAMap];
    }
}

- (void)didUpdateHeading:(CLHeading *)newHeading{
    [self.map setUserHeading:newHeading];
}

- (void)showsSegmentAction:(UISegmentedControl *)sender
{
    self.map.showsUserLocation = !sender.selectedSegmentIndex;
}

- (void)modeAction:(UISegmentedControl *)sender
{
    self.map.userTrackingMode = sender.selectedSegmentIndex;
}

- (void)returnAction
{
    [self.navigationController popViewControllerAnimated:YES];
}

- (void)dealloc
{
    [self.map removeObserver:self forKeyPath:@"showsUserLocation"];
}

#pragma mark - MAMapDelegate
- (void)map:(MAMap *)map didChangeUserTrackingMode:(MAUserTrackingMode)mode animated:(BOOL)animated
{
    self.modeSegment.selectedSegmentIndex = mode;
}

- (void)mapReady:(MAMap *)map{
    self.map.showsUserLocation = YES;

    [self startLocation];
    [self startLocationHeading];
    
    //自定义定位圈
    self.map.userLocation.title = @"您的位置在这里";
    MAUserLocationRepresentation *represent = [[MAUserLocationRepresentation alloc] init];
    represent.showsAccuracyRing = YES;
    represent.fillColor = [UIColor colorWithRed:1 green:0 blue:0 alpha:.3];
    represent.strokeColor = [UIColor lightGrayColor];
    represent.lineWidth = 2.f;
    represent.image = [UIImage imageNamed:@"userPosition"];
    [self.map updateUserLocationRepresentation:represent];
}

#pragma mark - NSKeyValueObservering

- (void)observeValueForKeyPath:(NSString *)keyPath ofObject:(id)object change:(NSDictionary *)change context:(void *)context
{
    if ([keyPath isEqualToString:@"showsUserLocation"])
    {
        NSNumber *showsNum = [change objectForKey:NSKeyValueChangeNewKey];
        
        self.showSegment.selectedSegmentIndex = ![showsNum boolValue];
    }
}

@end
